<?php

namespace SGalinski\SgMail\Service;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\SingletonInterface;
use TYPO3\CMS\Extbase\Configuration\BackendConfigurationManager;
use TYPO3\CMS\Extbase\Service\TypoScriptService;

/**
 * Returns the typoscript setup based on the page id
 *
 */
class TypoScriptSettingsService implements SingletonInterface {
	/**
	 * @inject
	 * @var \TYPO3\CMS\Extbase\Object\ObjectManagerInterface
	 */
	protected $objectManager;

	/**
	 * @var array
	 */
	protected static $typoScriptCache = [];

	/**
	 * Returns the typoscript settings of a given page and extension
	 *
	 * @param int $pageId
	 * @param string $extensionKey
	 * @return array
	 */
	public function getSettings($pageId, $extensionKey) {
		$pageId = (int) $pageId;
		if (!isset(self::$typoScriptCache[$extensionKey . $pageId])) {
			$tmpId = $_POST['id'];
			$_POST['id'] = $pageId;

			/** @var TypoScriptService $typoScriptService */
			$class = 'TYPO3\CMS\Extbase\Service\TypoScriptService';
			$typoScriptService = $this->objectManager->get($class);

			/** @var BackendConfigurationManager $configurationManager */
			$class = 'TYPO3\CMS\Extbase\Configuration\BackendConfigurationManager';
			$configurationManager = $this->objectManager->get($class);

			self::$typoScriptCache[$extensionKey . $pageId] = $typoScriptService->convertTypoScriptArrayToPlainArray(
				(array) $configurationManager->getTypoScriptSetup()['module.'][$extensionKey . '.']['settings.']
			);
			$_POST['id'] = $tmpId;
		}

		return self::$typoScriptCache[$extensionKey . $pageId];
	}
}
